Solar Arrays
============

.. autoclass:: physics.models.arrays.BasicArray
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: physics.models.arrays.BaseArray
   :members:
   :undoc-members:
   :show-inheritance: